@@ -22,7 +22,7 @@ class Devices(BaseModel, extra=Extra.ignore):
     alias: List[str] = []
     root_topic: str
     permitted_group: List[int]
-    dev_clt = None
+    dev_clt: None = None
 
 
 class Config(BaseSettings, extra=Extra.ignore):
